pub fn user_document_path(environment: &Environment) -> Option<PathBuf>Expand description
Where the user-level document lives, when this host says where that is.
pub fn user_document_path(environment: &Environment) -> Option<PathBuf>Where the user-level document lives, when this host says where that is.