pub fn variable_for(key: &SettingPath) -> StringExpand description
The variable that sets key, for a message that tells a user what to export.
pub fn variable_for(key: &SettingPath) -> StringThe variable that sets key, for a message that tells a user what to export.