pub struct Route { /* private fields */ }Expand description
One entry of a source’s routes.
Implementations
Sourceimpl Route
impl Route
Sourcepub fn repositories(&self) -> &[RepositoryPattern]
pub fn repositories(&self) -> &[RepositoryPattern]
The patterns, in the order written. Never empty.
Sourcepub fn to(&self) -> &SourceName
pub fn to(&self) -> &SourceName
The configured source an item this entry matches goes to.
Sourcepub fn matches(&self, repositories: &[Repository]) -> bool
pub fn matches(&self, repositories: &[Repository]) -> bool
Whether every one of repositories matches one of this entry’s patterns — false
for an item naming none.