attach_simulated_clock

Function attach_simulated_clock 

pub fn attach_simulated_clock(
    address: SocketAddr,
    client: usize,
) -> Result<SharedClock, String>
Attach to the coordinator at address as client client, answering a clock that runs on its virtual time.

Errors

A message naming the variable and the address when the coordinator cannot be reached or does not acknowledge the attach.