pub struct RenderedTemplate {
pub body: String,
pub digest: String,
pub answers: BTreeMap<String, Value>,
}Expand description
A rendered template: what onetaskgraph template render answers with.
Fields
body: StringThe rendered text.
digest: StringThe digest of every file of the chain these answers render, in first-load order:
sha256: and 64 lowercase hex digits. That is the order the render first read each
file, a template an expression named included, then any file of the chain it did not
read.
answers: BTreeMap<String, Value>Every declared variable and the value it rendered with — an answer, a default, or
null for an optional variable given neither.