pub fn process_clock(environment: &Environment) -> Result<SharedClock, String>Expand description
This process’s one clock, as environment asks for it.
Errors
A message naming the variable when its value is malformed, or when the coordinator it names cannot be reached.